console.log("euroloop");
if ($("#checked").val() != "1") $('[name="questSubmit"]').attr('disabled','disabled');
var qname = document.getElementById("qname").value;
var min = document.getElementById("min").value;
var max = document.getElementById("max").value;
// var betragins = append("<br />").text("INTERVIEWER: Mögliche Eingaben zw. '.$min.' und '.$max.'.").css("background-color", "yellow");
// var waehrins = append("<br />").append(" Auch Angaben in einer anderen Währung aufnehmen.");
var startnode = document.getElementById("ct_"+qname+"_1");
//alert("RTEST");
//startnode.parentNode.parentNode.parentNode.appendChild(document.getElementById('treuro'));
startnode.parentNode.parentNode.parentNode.appendChild(document.getElementById('euroloop'));
startnode.parentNode.parentNode.style.display="none";
document.getElementById("betragop").autocomplete = "off";
document.getElementById("unterop").autocomplete = "off";
document.getElementById("oberop").autocomplete = "off";
//initiate
var initstat = 0;
//Kat gennannt
if ($( "select[name='kategorie'] option:selected" ).val() != "" ) {
    // console.log('KAT genannt');
    initstat = 3;
} else {
    // console.log('KAT  nicht genannt');

}
//Bereich genannt
if (
   $("#oberop").val() != "" ||
   $("#unterop ").val() != "" ||
   //$("#bereichka ").is(':checked') ||
   //$("#bereichwn ").is(':checked') ||
   $("#oberka").is(':checked') ||
   $("#unterka ").is(':checked')) {
    initstat = 2;
    // console.log('Bereich genannt');
} else {
    // console.log('Bereich nicht genannt');

}
// Betrag genannt
if (
   $("#betragop").val() != "") {
    initstat = 1;
//    console.log('Betrag genannt');
} else {
    // console.log('Betrag nicht genannt');

}
//NEW Betrag und ka und wn leer
    // console.log('initstat = '+initstat );

if (initstat != 2 && initstat != 3)     document.getElementById("bereich").style.display="none";
if (initstat != 3) document.getElementById("kat").style.display="none";
if (initstat == 3) {
    $("#kat").show();
    $("#waehr").hide();
}
if ($( "select[name='waehrung'] option:selected" ).val() != 16) {
    document.getElementById("waehrtxt").style.display="none";
}
//switchfields
$("#betragka").click(function(){
    $("#bereich").show();
    $("#betragop").val('');
});
$("#betragwn").click(function(){
    $("#bereich").show();
    $("#betragop").val('');
});
$("#betragso").click(function(){
    $("#betragop").val('');
    $("#bereich").hide();
});
$("#betragop").focus(function(){
    $("#bereich").hide();
    $("#kat").hide();
    $("#waehr").show();
    $("#betragwn").prop('checked', false);
    $("#betragka").prop('checked', false);
    $("#betragso").prop('checked', false);
});
$("#bereichka").click(function(){
    $("#kat").show();
    $("#waehr").hide();
    $("#oberop").val('');
    $("#unterop").val('');
    $("#oberka").prop('checked', false);
    $("#unterka").prop('checked', false);
});
$("#bereichwn").click(function(){
    $("#kat").show();
    $("#waehr").hide();
    $("#oberop").val('');
    $("#unterop").val('');
    $("#oberka").prop('checked', false);
    $("#unterka").prop('checked', false);
});
$("#oberop").focus(function(){
    $("#kat").hide();
    $("#waehr").show();
    $("#bereichwn").prop('checked', false);
    $("#bereichka").prop('checked', false);
    $("#oberka").prop('checked', false);
});
$("#oberka").click(function(){
    $("#kat").hide();
    $("#waehr").show();
    $("#bereichwn").prop('checked', false);
    $("#bereichka").prop('checked', false);
    $("#oberop").val('');
});
$("#unterop").focus(function(){
    $("#kat").hide();
    $("#waehr").show();
    $("#bereichwn").prop('checked', false);
    $("#bereichka").prop('checked', false);
    $("#unterka").prop('checked', false);
});
$("#unterka").click(function(){
    $("#kat").hide();
    $("#waehr").show();
    $("#bereichwn").prop('checked', false);
    $("#bereichka").prop('checked', false);
    $("#unterop").val('');
});
$('select[name=waehrung]').change(function(){
    if ($( "select[name='waehrung'] option:selected" ).val() == 16) {
        $("#waehrtxt").show();
    }
});
$('#euroloop').change(function(){
    // if (!$("#betragso").is(':checked')) {
        $("#checked").val('0');
        $('[name="questSubmit"]').attr('disabled','disabled');
    // }
});
button = startnode;
button = document.getElementById("saveButton");

button.onclick = function() {
//button.addEventListener("click", function(event){
    //event.preventDefault();
    var values = {};
        values["checked"] = $("#checked").val();
        values["betragwaehr"] = $( "select[name='waehrung'] option:selected" ).text();

        values["betragop"] = $("#betragop").val();
        values["betragka"] = 0;
        values["betragwn"] = 0;
        values["betragso"] = 0;
        if ($("#betragka").is(':checked')) {values["betragka"] = 1;}
        if ($("#betragwn").is(':checked')) {values["betragwn"] = 1;}
        if ($("#betragso").is(':checked')) {values["betragso"] = 1;}

        values["oberop"] = $("#oberop").val();
        values["unterop"] = $("#unterop ").val();
        values["bereichka"] = 0;
        values["bereichwn"] = 0;
        values["unterka"] = 0;
        values["oberka"]= 0;
        if ($("#bereichka ").is(':checked')) {values["bereichka"] = 1;}
        if ($("#bereichwn ").is(':checked')) {values["bereichwn"] = 1;}
        if ($("#oberka").is(':checked')) {values["oberka"]= 1;}
        if ($("#unterka ").is(':checked')) {values["unterka"] = 1;}
        values["waehrung"] = $( "select[name='waehrung'] option:selected" ).val();
        values["waehrop"] = $("#waehrop").val();
        values["kategorie"] = $( "select[name='kategorie'] option:selected" ).val();
        values["katgrp"] = $("#katgrp").val();

    // CHECK EINGABEN
    var checkinput = 1;
    if ((values["betragop"]=="" || isNaN(parseInt(values["betragop"]))) && values["betragka"]==0 && values["betragwn"]==0 && values["betragso"]==0) {
        checkinput = 0;
        betragges = "Geben Sie eine Betrag ein oder wählen Sie 'keine Angaben' bzw. 'weiß nicht' !";
    }
    if ((values["betragka"]==1 || values["betragwn"]==1) && ((values["oberka"]==1 && values["unterka"]==1))) {
        checkinput = 0;
        betragges = "Geben Sie zumindest einen Betrag ein oder wählen Sie 'keine Angaben' bzw. 'weiß nicht' !";
    }
    if ((values["betragka"]==1 || values["betragwn"]==1) && (
            (values["unterka"]==0 && (values["unterop"]=="" || isNaN(parseInt(values["unterop"]))) && values["bereichka"]==0 && values["bereichwn"]==0) ||
            (values["oberka"]==0 && (values["oberop"]=="" || isNaN(parseInt(values["oberop"]))) && values["bereichka"]==0 && values["bereichwn"]==0))) {
        checkinput = 0;
        betragges = "Geben Sie eine Ober oder Untergrenze ein oder wählen Sie 'keine Angaben' bzw. 'weiß nicht' !";
    }
    if ((values["betragka"]==1 || values["betragwn"]==1) && (
        (values["unterka"]==0 && values["oberka"]==0 && values["bereichka"]==0 && values["bereichwn"]==0 && parseInt(values["unterop"])>=parseInt(values["oberop"])))) {
        checkinput = 0;
        betragges = "Die Untergrenze muss kleiner als die Obergrenze sein!";
    }
    if (values["kategorie"] == "" && values["waehrung"] == "") {
        checkinput = 0;
        betragges = "Wählen Sie eine Währung aus!";
    }
    if (((values["betragka"]==1 || values["betragwn"]==1) && (values["bereichka"]==1 || values["bereichwn"]==1)) &&
        (values["kategorie"] == ""))  {
        checkinput = 0;
        betragges = "Wählen Sie eien Kategorie aus der Liste oder 'keine Angaben' bzw. 'weiß nicht' !";
    }
    console.log("Betrag: "+values["betragop"]+"parseInt: "+parseInt(values["betragop"])+" -Min: "+min+"-Max: "+max+"-BetragKA: "+values["betragka"]+"-BetragWN: "+values["betragwn"]+"-Sonder: "+values["betragso"]);
    if ((parseInt(values["betragop"])<min || parseInt(values["betragop"])>max) && values["betragka"]==0 && values["betragwn"]==0) {
        checkinput = 0;
        betragges = "Tragen Sie einen Betrag zwischen "+min+" und "+max+" ein!";
    }
    if ((values["betragka"]==1 || values["betragwn"]==1) && values["bereichka"]==0 && values["bereichwn"]==0 &&
        (parseInt(values["oberop"])<min || parseInt(values["oberop"])>max) && values["oberka"]!=1) {
        checkinput = 0;
        betragges = "Tragen Sie eine Obergrenze zwischen "+min+" und "+max+" ein!";
    }
    if ((values["betragka"]==1 || values["betragwn"]==1) && values["bereichka"]==0 && values["bereichwn"]==0 &&
        (parseInt(values["unterop"])<min || parseInt(values["unterop"])>max) && values["unterka"]!=1) {
        checkinput = 0;
        betragges = "Tragen Sie eine Untergrenze zwischen "+min+" und "+max+" ein!";
    }
    if (checkinput == 1 && values["betragso"]== 0)  {
        console.log("TEST3");
        var betragnr = '';
        var betragtxt = '';
        var betragwaehr = '';
        var betragges = '';
        betragwaehr = $( "select[name='waehrung'] option:selected" ).text();
        if (values["waehrung"] == 16)  betragwaehr = $("#waehrop").val();
        var varify = false;
		var neg = '';
        var quest =  "Ist das richtig (OK)?";
        //BETRAG GENANNT
        if (parseInt($("#betragop").val()) <= max && parseInt($("#betragop").val()) >= min && $("#betragop").val() != "") {
            betragnr = parseInt($("#betragop").val());
            if (betragnr<0) {
				betragnr = betragnr * (-1);
				neg = '-';
			}
            betragstrg = betragnr.toString();
            console.log("TEST4.2 ("+neg+")"+betragnr+" "+betragstrg.length);
            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt = neg+betragstrg;

            var betragges = "Sie haben angegeben, dass der Betrag bei "+betragwaehr+" "+betragtxt+" liegt.";
            // var betragges = "Sie haben angegeben, dass der Betrag bei "+betragwaehr+" "+betragnr+" (in Worten "+betragtxt+") liegt.";
        }
        //BEREICH GENANNT
        else if (parseInt($("#oberop").val()) <= max && parseInt($("#oberop").val()) >= min && parseInt($("#unterop").val()) <= max && parseInt($("#unterop").val()) >= min && $("#oberop").val() != "" && $("#unterop").val() != "") {
            betragnr = parseInt($("#unterop").val());
            if (betragnr<0) {
				betragnr = betragnr * (-1);
				neg = '-';
			}
            betragstrg = betragnr.toString();
            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt = neg+betragstrg;
            neg = '';
			betragnr = parseInt($("#oberop").val());
            if (betragnr<0) {
				betragnr = betragnr * (-1);
				neg = '-';
			}
            betragstrg = betragnr.toString();
            if (betragstrg.length > 6)  betragtxt = betragtxt +" und "+ neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt =  betragtxt +" und "+ neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt =  betragtxt +" und "+ neg+betragstrg;
            // betragnr = $("#unterop").val()+" und "+$("#oberop").val();
            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise zwischen "+betragwaehr+" "+betragtxt+" liegt.";
        }
        //NUR OBERGRENZE GENANNT
        else if (parseInt($("#oberop").val()) <= max && parseInt($("#oberop").val()) >= min && $("#oberop").val() != "") {
            betragnr = parseInt($("#oberop").val());
            if (betragnr<0) {
				betragnr = betragnr * (-1);
				neg = '-';
			}
            betragstrg = betragnr.toString();
            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt = neg+betragstrg;
            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise unter "+betragwaehr+" "+betragtxt+" liegt.";
        }
        //NUR UNTERGRENZE GENANNT
        else if (parseInt($("#unterop").val()) <= max && parseInt($("#unterop").val()) >= min && $("#unterop").val() != "") {
            betragnr = parseInt($("#unterop").val());
            if (betragnr<0) {
				betragnr = betragnr * (-1);
				neg = '-';
			}
            betragstrg = betragnr.toString();
            if (betragstrg.length > 6)  betragtxt = neg+betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt = neg+betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt = neg+betragstrg;
            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise über "+betragwaehr+" "+betragtxt+" liegt.";
        }
        //KATEGORIE GENANNT
        else if (values["kategorie"] != "" && values["kategorie"] != "1" && values["kategorie"] != "2") {
            //betragwaehr = $("#waehr").val();
            let intervals = {
                "A" : {
                    "A" : {min: 1,max: 100,mw: 50},
                    "B" : {min: 101,max: 200,mw: 150},
                    "C" : {min: 201,max: 300,mw: 250},
                    "D" : {min: 301,max: 400,mw: 350},
                    "E" : {min: 401,max: 500,mw: 450},
                    "F" : {min: 501,max: 750,mw: 625},
                    "G" : {min: 751,max: 1000,mw: 875},
                    "H" : {min: 1001,max: 1500,mw: 1250},
                    "I" : {min: 1501,max: 2000,mw: 1750},
                    "J" : {min: 2001,max: 3000,mw: 1500},
                    "K" : {min: 3001,max: 5000,mw: 4000},
                    "L" : {min: 5001,max: 7500,mw: 6250},
                    "M" : {min: 7501,max: 10000,mw: 8750},
                    "N" : {min: 10001,max: 25000,mw: 1750},
                    "O" : {min: 25001,max: 50000,mw: 3750},
                    "P" : {min: 50001,max: "",mw: 50001}
                },
                "B" : {
                    "A" : {min: 1,max: 10000,mw: 5000},
                    "B" : {min: 10001,max: 50000,mw: 30000},
                    "C" : {min: 50001,max: 75000,mw: 62500},
                    "D" : {min: 75001,max: 100000,mw: 87500},
                    "E" : {min: 100001,max: 150000,mw: 125000},
                    "F" : {min: 150001,max: 200000,mw: 175000},
                    "G" : {min: 200001,max: 300000,mw: 250000},
                    "H" : {min: 300001,max: 400000,mw: 350000},
                    "I" : {min: 400001,max: 500000,mw: 450000},
                    "J" : {min: 500001,max: 750000,mw: 625000},
                    "K" : {min: 750001,max: 1000000,mw: 875000},
                    "L" : {min: 1000001,max: 3000000,mw: 2000000},
                    "M" : {min: 3000001,max: 5000000,mw: 4000000},
                    "N" : {min: 5000001,max: 10000000,mw: 7500000},
                    "O" : {min: 10000001,max: "",mw: 10000001}
                },
                "C" : {
                    "A" : {min: 1,max: 1000,mw: 500},
                    "B" : {min: 1001,max: 2500,mw: 1250},
                    "C" : {min: 2501,max: 5000,mw: 3750},
                    "D" : {min: 5001,max: 7500,mw: 6250},
                    "E" : {min: 7501,max: 10000,mw: 8750},
                    "F" : {min: 10001,max: 15000,mw: 12500},
                    "G" : {min: 15001,max: 20000,mw: 17500},
                    "H" : {min: 20001,max: 25000,mw: 22500},
                    "I" : {min: 25001,max: 30000,mw: 27500},
                    "J" : {min: 30001,max: 35000,mw: 32500},
                    "K" : {min: 35001,max: 40000,mw: 37500},
                    "L" : {min: 40001,max: 50000,mw: 45000},
                    "M" : {min: 50001,max: 75000,mw: 62500},
                    "N" : {min: 75001,max: 100000,mw: 77500},
                    "O" : {min: 100001,max: 200000,mw: 150000},
                    "P" : {min: 200001,max: 300000,mw: 250000},
                    "Q" : {min: 300001,max: 500000,mw: 400000},
                    "R" : {min: 500001,max: 10000000,mw: 750000},
                    "S" : {min: 10000001,max: "",mw: 10000001}
                }
            };
            let katmin = intervals[values["katgrp"]][values["kategorie"]]["min"];
            let katmax = intervals[values["katgrp"]][values["kategorie"]]["max"];
            let zwtext = "";
            betragstrg = katmin.toString();
            if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
            else betragtxt = betragstrg;
            let katmintxt = betragtxt;
            if (katmax!="") {
                betragstrg = katmax.toString();
                if (betragstrg.length > 6)  betragtxt = betragstrg.substring(0, betragstrg.length-6)+"."+betragstrg.substring(betragstrg.length-6, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
                else if (betragstrg.length > 3) betragtxt = betragstrg.substring(0, betragstrg.length-3)+"."+betragstrg.substring(betragstrg.length-3, betragstrg.length);
                else betragtxt = betragstrg;
                katmaxtxt = betragtxt;
            }
            if (katmax!="") zwtext = "zwischen Euro "+katmintxt+" und "+katmaxtxt+"";
            else zwtext = "über Euro "+katmintxt+"";
            var betragges = "Sie haben angegeben, dass der Betrag schätzungsweise "+zwtext+" (Kategorie: "+values["kategorie"]+") liegt.";
        }
        //NICHTSGENANNT
        else {
            varify = true;
        }
        values["betragtxt"]=betragges;
        if (varify == false) {
        varify = confirm(betragges+"\n\n"+quest);
        }
        if (varify  == true) {
            $('[name="questSubmit"]').removeAttr('disabled');
            document.getElementById('betragtxt').style.color = 'black';
            document.getElementById("betragtxt").style.fontWeight = "bold";
            $("#checked").val('1');
            values["checked"] = '1';
                    var value = "[{ ";
            var komma = '';
            for (var key in values) {
                // console.log(values[key]);
                value = value + komma+'"'+key+'": "'+values[key]+'"';
                komma = ", ";
            }
            value = value + " }]";
            //value = "TEST";
            startnode.value=value;
        } else {
            betragges = "Korrigieren Sie die Eingabe und klicken Sie erneut auf Überprüfen!";
            document.getElementById('betragtxt').style.color = 'red';
            document.getElementById("betragtxt").style.fontWeight = "bold";

            //betragges = betragges.fontcolor("red");
        }
    } else if ( values["betragso"] == 1) {
        $("#checked").val('1');
        values["checked"] = '1';
                var value = "[{ ";
        var komma = '';
        for (var key in values) {
            // console.log(values[key]);
            value = value + komma+'"'+key+'": "'+values[key]+'"';
            komma = ", ";
        }
        value = value + " }]";
        //value = "TEST";
        startnode.value=value;

        console.log("TEST Sonder");
        $('[name="questSubmit"]').removeAttr('disabled');
        betragges = "Klicken Sie auf weiter!";
        document.getElementById('betragtxt').style.color = 'black';
        document.getElementById("betragtxt").style.fontWeight = "bold";
    } else {
        //betragges = "Überprüfen Sie Ihre Eingabe!";
        document.getElementById('betragtxt').style.color = 'red';
        document.getElementById("betragtxt").style.fontWeight = "bold";
    }
    $("#betragtxt").text("\n\n"+betragges+"\n\n");
    console.log("startnode.value"+startnode.value);
}
